# Reddit Post Scraping Tool (RPST)
This is a dummy package managed by the developer of **Reddit Post Scraping Tool** to prevent name squatting. The official PyPI Package/GitHub Repository name of the tool is [reddit-post-scraping-tool](https://pypi.python.org/pypi/reddit-post-scraping-tool). This package ensures that if you run `pip install rpst` knowingly or by mistake you will end up with `reddit-post-scraping-tool`, which can then be called with `rpst` (e.g `rpst --help`).
***
<a href="https://www.buymeacoffee.com/_rly0nheart"><img src="https://img.buymeacoffee.com/button-api/?text=Buy me a coffee&emoji=&slug=_rly0nheart&button_colour=40DCA5&font_colour=ffffff&font_family=Comic&outline_colour=000000&coffee_colour=FFDD00" /></a>

![me](https://github.com/bellingcat/reddit-post-scraping-tool/assets/74001397/21e0bb33-7a84-45d6-92ba-00e40891ba31)
